/******************************************************************************/
/*                                                                            */
/*          SAS Program for TIMSS Advanced 2008 User Guide Example 4          */
/*            TIMSS Advanced 2008 International Report Exhibit 6.5            */
/*                                                                            */
/******************************************************************************/

* Specify the path for the SAS data files following the format x:\xxx\ ;
* <datpath> must be edited ;

LIBNAME TA08 "<datpath>" ;

* Issue the include command to include the JACKGPV macro in the program ;
* <macpath> must be edited following the format x:\xxx\ ;

%INCLUDE "<macpath>JACKPV.SAS" ;

* Get and sort the school data ;

PROC SORT DATA = TA08.MCGALLM2 OUT = MCGALLM2 ;
     BY IDCNTRY IDSCHOOL ;

* Get and sort the student data ;

PROC SORT DATA = TA08.MSGALLM2 OUT = MSGALLM2 ;
     BY IDCNTRY IDSCHOOL ;

* Merge the two files ;

DATA MERGED ;
     MERGE MCGALLM2 (IN = INMCG)
           MSGALLM2 (IN = INMSG) ;
     BY IDCNTRY IDSCHOOL ;
     IF INMCG AND INMSG ;

* Read the merged file and select cases of interest ;

DATA MERGED ;
     SET MERGED ;

     * Select cases with no missing data ;

     IF NMISS (MCDGPPSC) = 0 ;

* Define formats for the variables used ;

PROC FORMAT LIBRARY = WORK ;

 VALUE COUNTRY
   051 = 'ARMENIA'
   364 = 'IRAN, ISLAMIC REP. OF'
   380 = 'ITALY'
   422 = 'LEBANON'
   528 = 'NETHERLANDS'
   578 = 'NORWAY'
   608 = 'PHILIPPINES'
   643 = 'RUSSIAN FEDERATION'
   705 = 'SLOVENIA'
   752 = 'SWEDEN' ;

 VALUE PPSC
     1 = 'HIGH'
     2 = 'MEDIUM'
     3 = 'LOW' ;

* Invoke the JACKPV macro to compute the statistics ;

%JACKPV (TOTWGT, JKZONE, JKREP, 75, IDCNTRY MCDGPPSC, MSMMAT0, 5, MERGED) ;

* Print the results ;

PROC PRINT DATA = FINAL NOOBS ;
     VAR IDCNTRY MCDGPPSC N TOTWGT MNPV MNPV_SE PCT PCT_SE ;
     FORMAT IDCNTRY COUNTRY. MCDGPPSC PPSC. N 6.0 TOTWGT 10.0
            MNPV MNPV_SE PCT PCT_SE 6.2 ;
RUN ;
