/******************************************************************************/
/*                                                                            */
/*               Sample SAS Program to Invoke the JACKGEN Macro               */
/*                       TIMSS Advanced 2008 User Guide                       */
/*                                                                            */
/******************************************************************************/

* Specify the path for the SAS data files following the format x:\xxx\ ;
* <datpath> must be edited ;

LIBNAME TA08 "<datpath>" ;

* issue the include command to include the JACKGEN macro in the program ;
* <macpath> must be edited following the format x:\xxx\ ;

%INCLUDE "<macpath>JACKGEN.SAS" ;

* Get the student data and select cases of interest ;

DATA MSGALLM2 ;
     SET TA08.MSGALLM2 ;

     * Select cases with no missing data ;

     WHERE NMISS (ITSEX, MSDAGE) = 0 ;

* Define formats for the variables used ;

PROC FORMAT LIBRARY = WORK ;

 VALUE COUNTRY
   051 = 'ARMENIA'
   364 = 'IRAN, ISLAMIC REP. OF'
   380 = 'ITALY'
   422 = 'LEBANON'
   528 = 'NETHERLANDS'
   578 = 'NORWAY'
   608 = 'PHILIPPINES'
   643 = 'RUSSIAN FEDERATION'
   705 = 'SLOVENIA'
   752 = 'SWEDEN' ;

 VALUE SEX
     1 = 'GIRL'
     2 = 'BOY' ;

* Invoke the JACKGEN macro to compute the statistics ;

%JACKGEN (TOTWGT, JKZONE, JKREP, 75, IDCNTRY ITSEX, MSDAGE, MSGALLM2) ;

* Print the results ;

PROC PRINT DATA = FINAL NOOBS ;
     VAR IDCNTRY ITSEX N TOTWGT MNX MNX_SE PCT PCT_SE ;
     FORMAT IDCNTRY COUNTRY. ITSEX SEX. N 6.0 TOTWGT 10.0
            MNX MNX_SE PCT PCT_SE 6.2 ;
RUN ;
