/******************************************************************************/
/*                                                                            */
/*               Sample SAS Program to Invoke the JACKREG Macro               */
/*                       TIMSS Advanced 2008 User Guide                       */
/*                                                                            */
/******************************************************************************/

* Specify the path for the SAS data files following the format x:\xxx\ ;
* <datpath> must be edited ;

LIBNAME TA08 "<datpath>" ;

* Issue the include command to include the jackreg macro in the program ;
* <macpath> must be edited following the format x:\xxx\ ;

%INCLUDE "<macpath>JACKREG.SAS" ;

* Get the student data and select cases of interest ;

DATA MSGALLM2 ;
     SET TA08.MSGALLM2 ;

     * Select cases with no missing data ;

     WHERE NMISS (ITSEX, MSDAGE) = 0 ;

     * Dummy recode of ITSEX ;

     REGSEX = ITSEX - 1 ;

* Define formats for the variables used ;

PROC FORMAT LIBRARY = WORK ;

 VALUE COUNTRY
   051 = 'ARMENIA'
   364 = 'IRAN, ISLAMIC REP. OF'
   380 = 'ITALY'
   422 = 'LEBANON'
   528 = 'NETHERLANDS'
   578 = 'NORWAY'
   608 = 'PHILIPPINES'
   643 = 'RUSSIAN FEDERATION'
   705 = 'SLOVENIA'
   752 = 'SWEDEN' ;

* Invoke the JACKREG macro to compute the statistics ;

%JACKREG (TOTWGT, JKZONE, JKREP, 75, IDCNTRY, REGSEX, MSDAGE, MSGALLM2) ;

* Print the results ;

PROC PRINT DATA = REG NOOBS ;
     VAR IDCNTRY N MULT_RSQ SS_TOTAL SS_REG B00 B00_SE B01 B01_SE ;
     FORMAT IDCNTRY COUNTRY. N 6.0 MULT_RSQ 5.3 SS_TOTAL SS_REG 10.0
            B00 B00_SE B01 B01_SE 6.2 ;
RUN ;
