*                                                                              .
*                 SAS Program to Score the TIMSS Advanced 2008                 .
*                          Advanced Mathematics Items                          .
*                        TIMSS Advanced 2008 User Guide                        .
*                                                                              .

SET MPRINT=ON.

DEFINE SCOREIT (TYPE  = !CHAREND('/') /
                ITEM  = !CHAREND('/') /
                RIGHT = !CHAREND('/') /
                NR    = !CHAREND('/') /
                NA    = !CHAREND('/') /
                OM    = !CHAREND('/') /
                OTHER = !CHAREND('/') ) .

* Code for multiple-choice items .

 !IF (!UPCASE(!TYPE)=MC) !THEN
    !DO !I !IN (!ITEM) .
       RECODE !I (!RIGHT = 1      )
                 (!NR    = 0      ) /* Not Reached      */
                 (!NA    = SYSMIS ) /* Not Administered */
                 (!OM    = 0      ) /* Omitted          */
                 (!OTHER = 0      ) /* Other Missing    */
                 (ELSE   = 0      ) .
    !DOEND .
 !IFEND .

 * Code for constructed-response items .

 !IF (!UPCASE(!TYPE)=CR) !THEN
    !DO !I !IN (!ITEM).
       RECODE !I (10 THRU 19 = 1      )
                 (20 THRU 29 = 2      )
                 (30 THRU 39 = 3      )
                 (70 THRU 79 = 0      )
                 (!NR        = 0      ) /* Not Reached      */
                 (!NA        = SYSMIS ) /* Not Administered */
                 (!OM        = 0      ) /* Omitted          */
                 (!OTHER     = 0      ) /* Other Missing    */
                 (ELSE       = 0      ).
    !DOEND .
 !IFEND .

!ENDDEFINE.

DEFINE DOIT (COUNTRY = !CHAREND('/') ) .

* Specify the path for the SPSS data files following the format x:\xxx\ .
* <path> must be edited .

!LET !LIBDAT = !UNQUOTE("<path>") .

* Country loop .

!DO !CTY !IN (!COUNTRY) .

* Get the student achievement data .

ADD FILES
  / FILE = !QUOTE(!CONCAT(!LIBDAT,'MSA',!CTY,'M2.SAV')) .

* Score multiple-choice items with A key .

SCOREIT  Type  = MC      /
         Item  = MA13002  MA13007  MA13011  MA13021  MA23185  MA23064  MA23082
                 MA23208  MA23080  MA23041  /
         RIGHT = 1       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with B key .

SCOREIT  Type  = MC      /
         Item  = MA13004  MA13018  MA13019  MA13024  MA23005  MA23176  MA23042
                 MA23021  MA23004  MA23063  MA23050  /
         RIGHT = 2       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with C key .

SCOREIT  Type  = MC      /
         Item  = MA13009  MA13012  MA13015  MA13020  MA23076  MA23098  MA23144
                 MA23045  MA23151  /
         RIGHT = 3       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with D key .

SCOREIT  Type  = MC       /
         Item  = MA13001  MA13006  MA13008  MA13016  MA23206  MA23020  MA23069
                 MA23039  MA23055  MA23133  MA23158  MA23182  /
         RIGHT = 4       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with E key .

SCOREIT  Type  = MC       /
         Item  = MA13003  MA13013  MA13017  /
         RIGHT = 5       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score Constructed-Response Items .

SCOREIT  Type  = CR      /
         Item  = MA13025A MA13025B MA13026A MA13026B MA13027  MA13028  MA13029
                 MA23145  MA23187  MA23201  MA23154  MA23166  MA23043  MA23054
                 MA23131A MA23131B MA23157  MA23094  MA23135  MA23165  MA23159
                 MA23198  MA23141  MA23035A MA23035B MA23170  /
         RIGHT =  0      /
         NR    = 96      /
         NA    = sysmis  /
         OM    = 99      /
         OTHER = 90      .

EXECUTE.

* Save the student data .

SAVE OUTFILE = !QUOTE(!CONCAT(!LIBDAT,'MSC',!CTY,'M2.SAV')) .

!DOEND .

!ENDDEFINE .

* Specify the list of countries to be processed .

DOIT COUNTRY = ARM IRN ITA LBN NLD NOR PHL RUS SVN SWE .
